pub struct DynamicallyLinkedNode {
pub handle: Box<dyn Node>,
pub _library: Library,
}Expand description
This struct represents a dynamically linked node.
It loads the node from a shared library at runtime, storing the handle as a Box<dyn Node>.
It’s really important to store the library as well, because once the library is dropped the handle will be invalid.
Fields
handle: Box<dyn Node>The Node object the runtime will use
_library: LibraryAuto Trait Implementations
impl !RefUnwindSafe for DynamicallyLinkedNode
impl !UnwindSafe for DynamicallyLinkedNode
impl Freeze for DynamicallyLinkedNode
impl Send for DynamicallyLinkedNode
impl Sync for DynamicallyLinkedNode
impl Unpin for DynamicallyLinkedNode
impl UnsafeUnpin for DynamicallyLinkedNode